@@ -37,12 +37,18 @@
 #include <Rcpp/Named.h>
 
 #include <Rcpp/S4.h>
+#include <Rcpp/Reference.h>
 #include <Rcpp/clone.h>
 #include <Rcpp/grow.h>
 #include <Rcpp/Dimension.h>
 #include <Rcpp/Environment.h>
 #include <Rcpp/Evaluator.h>
+
 #include <Rcpp/Vector.h>
+#include <Rcpp/sugar/nona/nona.h>
+#include <Rcpp/Fast.h>
+#include <Rcpp/Extractor.h>
+
 #include <Rcpp/XPtr.h>
 #include <Rcpp/Symbol.h>
 #include <Rcpp/Language.h>
