@@ -73,13 +73,16 @@ RCPP_SIMPLE_EXCEPTION_CLASS(not_a_matrix, "not a matrix")
 RCPP_SIMPLE_EXCEPTION_CLASS(index_out_of_bounds, "index out of bounds")
 RCPP_SIMPLE_EXCEPTION_CLASS(parse_error, "parse error") 
 RCPP_SIMPLE_EXCEPTION_CLASS(not_s4, "not an S4 object")
+RCPP_SIMPLE_EXCEPTION_CLASS(not_reference, "not an S4 object of a reference class")
 RCPP_SIMPLE_EXCEPTION_CLASS(no_such_slot, "no such slot")
+RCPP_SIMPLE_EXCEPTION_CLASS(no_such_field, "no such field")
 RCPP_SIMPLE_EXCEPTION_CLASS(not_a_closure, "not a closure")
 RCPP_SIMPLE_EXCEPTION_CLASS(no_such_function, "no such function")
 RCPP_SIMPLE_EXCEPTION_CLASS(unevaluated_promise, "promise not yet evaluated")
 
 RCPP_EXCEPTION_CLASS(not_compatible, message )
 RCPP_EXCEPTION_CLASS(S4_creation_error, std::string("error creating object of S4 class : ") + message )
+RCPP_EXCEPTION_CLASS(reference_creation_error, std::string("error creating object of reference class : ") + message )
 RCPP_EXCEPTION_CLASS(no_such_binding, std::string("no such binding : '") + message + "'" )
 RCPP_EXCEPTION_CLASS(binding_not_found, std::string("binding not found: '") + message + "'" )
 RCPP_EXCEPTION_CLASS(binding_is_locked, std::string("binding is locked: '") + message + "'" )
