@@ -22,7 +22,10 @@
 #ifndef RCPP_SUGAR_H
 #define RCPP_SUGAR_H
 
+#include <Rcpp/sugar/block/block.h>
+
 #include <Rcpp/sugar/operators/operators.h>
 #include <Rcpp/sugar/functions/functions.h>
+#include <Rcpp/sugar/matrix/matrix_functions.h>
 
 #endif
