@@ -23,9 +23,7 @@
 
 namespace Rcpp{
 	exception::exception( const char* message_, const char* file, int line) : message(message_){
-		SEXP call = PROTECT( Rf_lang2( Rf_install("rcpp_set_current_stack_trace") , stack_trace(file,line) ) ) ;
-		Rf_eval( call, R_FindNamespace( Rf_mkString( "Rcpp") ) ) ;
-		UNPROTECT(1) ;
+		rcpp_set_stack_trace( stack_trace(file,line) ) ;
 	}
 	exception::~exception() throw(){}
 
@@ -36,6 +34,7 @@ RCPP_EXCEPTION_WHAT(exception)
 
 RCPP_EXCEPTION_WHAT(not_compatible)
 RCPP_EXCEPTION_WHAT(S4_creation_error)
+RCPP_EXCEPTION_WHAT(reference_creation_error)
 RCPP_EXCEPTION_WHAT(no_such_binding)
 RCPP_EXCEPTION_WHAT(binding_not_found)
 RCPP_EXCEPTION_WHAT(binding_is_locked)
@@ -51,7 +50,9 @@ RCPP_SIMPLE_EXCEPTION_WHAT(not_a_matrix, "not a matrix" )
 RCPP_SIMPLE_EXCEPTION_WHAT(index_out_of_bounds, "index out of bounds" )
 RCPP_SIMPLE_EXCEPTION_WHAT(parse_error, "parse error") 
 RCPP_SIMPLE_EXCEPTION_WHAT(not_s4, "not an S4 object" )
+RCPP_SIMPLE_EXCEPTION_WHAT(not_reference, "not a reference S4 object" )
 RCPP_SIMPLE_EXCEPTION_WHAT(no_such_slot, "no such slot" )
+RCPP_SIMPLE_EXCEPTION_WHAT(no_such_field, "no such field" )
 RCPP_SIMPLE_EXCEPTION_WHAT(not_a_closure, "not a closure" )
 RCPP_SIMPLE_EXCEPTION_WHAT(no_such_function, "no such function" )
 RCPP_SIMPLE_EXCEPTION_WHAT(unevaluated_promise, "promise not yet evaluated" )
